// COPYRIGHT 

#ifndef KPP_INTERFACE_WALK_H
#define KPP_INTERFACE_WALK_H

/*****************************************
 INCLUDES
*******************************************/

#include "KineoModuleManager/kppModuleInterface.h"
#include "KineoGUI/kppGUIModuleInterface.h"
#include "KineoController/kppUICommand.h"

#include "hppWalkPlanner/hppWalkPlanner.h"
#include "kppInterface/kppInterface.h"


KIT_PREDEF_CLASS(CkppInterfaceWalk);


/*****************************************
 CLASS
*******************************************/

#define FLAG_SELF_COL // if check self-collision


class CkppInterfaceWalk : public CkppInterface
{
  
public:
  
  virtual ~CkppInterfaceWalk();
  
  static CkppInterfaceWalkShPtr create();
  
  // methods inherited from CkppModuleInterface
  
  virtual std::string name() const;
  
  virtual void getMenuUICommandLists(const CkppMainWindowUICommandFactoryConstShPtr& i_commandFactory,
				     std::vector< CkppUICommandListShPtr > & o_menuCommandListVector);
  
protected:
  
  CkppInterfaceWalk(ChppWalkPlanner* inHppPlanner);

protected:
  
  // List Of Commands
   
  /// command to Solve a planner problem
  CkppUICommandShPtr attCommandSolvePlanner   ;
  /// command to Solve a planner problem
  CkppUICommandShPtr attCommandSetConfig   ;
  /// command to output the motion
  CkppUICommandShPtr attCommandOutputMotion   ;
  /// command to load obstacle by obstacle server
  CkppUICommandShPtr attCommandLoadObstacle;
  /// command to Load HRP2
  CkppUICommandShPtr attCommandLoadHRP2;

  /// Planner associed to the interface
  ChppWalkPlanner *attHppWalkPlanner;
     
public:

  /**
    \brief get the Planner associed to the Interface
    \return a hppWalkPlanner
  */
  ChppWalkPlanner *hppWalkPlanner() {return attHppWalkPlanner;};

  /**
     \brief Store planner associed to the Interface
     planner is stored both as walk planner and as generic planner.
     \param planner : a hppWalkPlanner
  */
  void hppWalkPlanner(ChppWalkPlanner *planner );

};

// function use to compile the KPP license
extern "C" KPP_ADDON_API int initializeModule(CkppModuleInterfaceShPtr& o_moduleInterface);

#endif 
